% armsheet.cls 
% Class file for Ars Magica Character Sheets
% (C) 1998: Hans Georg Schaathun <georg@ii.uib.no>
% $Id: armsheet.cls,v 1.1 1998/04/22 12:47:42 georg Exp georg $
%
% This file is distributed under the GNU public license.

\NeedsTeXFormat{LaTeX2e}
\ProvidesClass{armsheet}[1998/04/21 v$Revision: 1.1 $ ArM Character Sheet]
\LoadClass[a4paper]{report}
\RequirePackage{hggothic,armsheet,ifthen,array,arrayjob}
\nofiles

\def\CopyRight{{%
  \realsmall\selectfont
  \normalfont\copyright\ 
  \swabfamily 1998 Hans Georg Schaathun 
  $<$georg{\normalfont @}ii.uib.no$>$}}

%
% Boxes
%

\newsavebox{\abilitybox}
\newsavebox{\combatbox}
\newsavebox{\bodybox}
\newsavebox{\statbox}
\newsavebox{\armourbox}
\newsavebox{\personalitybox}
\newsavebox{\reputationbox}
\newsavebox{\vfbox}
\newsavebox{\equipmentbox}
\newsavebox{\troupebox}
\newsavebox{\topbox}
\newsavebox{\spellbox}

%
% Grog
%

\newenvironment{grog}{%
  \document\printfamily\usual
  \def\CharacterType{Grog Character}
  \def\AbilityNumber{18}
  \def\vfNumber{5}
  \def\repNumber{2}
  \grog@reputations
}{%
  \input{grogbox.tex}
  \input{grog.tex}
  \enddocument
}

%
% Companion
%

\def\mundane@counts{%
  \def\AbilityNumber{30}
  \def\vfNumber{11}
  \def\repNumber{3}
}

\newenvironment{companion}{%
  \document\printfamily\usual
  \def\CharacterType{Companion Character}
  \mundane@counts
}{%
  \input{boxdef.tex}
  \input{mundane.tex}
  \enddocument
}

% 
% Magus
% 

\newenvironment{magus}{%
  \document\printfamily\usual
  \def\CharacterType{Magu\s\ Character}
  \mundane@counts
  \def\spellNumber{18}
}{%
  \input{boxdef.tex}
  \input{mundane.tex}\newpage
  \input{hermetic.tex}\newpage
  \usebox{\spellbox}
  \enddocument
}

\newenvironment{spells}{%
}{%
}

%
% Empty sheets
%

\def\m@default{%
  \begin{abilities}\end{abilities}
  \begin{equipment}\end{equipment}
  \begin{personality}\end{personality}
  \begin{vf}\end{vf}
  \begin{reputations}\end{reputations}
}
\def\h@default{%
  \m@default
  \begin{grimoire}\end{grimoire}
}

\def\makenpccompanion{
  \begin{companion}
    \def\CharacterType{NPC Companion} \m@default
  \end{companion}
}
\def\makenpcgrog{
  \begin{grog}
    \def\CharacterType{NPC Grog} \m@default
  \end{grog}
}
\def\makenpcmagus{
  \begin{magus}
    \def\CharacterType{NPC Magu\s} \h@default
  \end{magus}
}
\def\makecompanion{
  \begin{companion} \m@default \end{companion}
}
\def\makegrog{
  \begin{grog} \m@default \end{grog}
}
\def\makemagus{
  \begin{magus} \h@default \end{magus}
}

%
% Abilities
%

\newcommand{\AbilityLine}[4][\hspace{64pt}]{#2 & \lb #1\rb & #3 & #4 \\\hline}
\newcounter{abilityline}

\def\Anability{\addtocounter{abilityline}{-1}\AbilityLine}

\newenvironment{abilities}{%
  \lrbox{\abilitybox}
  \minipage{21pc}
  \center
  {\minorheading Abilitie\s}
  \setcounter{abilityline}{\AbilityNumber}
  \begin{tabular}{>{\handfamily\FrakChar}l>{\handfamily}c|%
                  >{\handfamily}c|>{\handfamily}c}
    \multicolumn{2}{l}{}&
    \multicolumn{1}{c}{Scr}&
    \multicolumn{1}{c}{Exp}\\ \hline
}{%
    \whiledo{\value{abilityline} > 0}{%
      \addtocounter{abilityline}{-1}%
      \AbilityLine{}{}{}%
    }
    \hbox{\hspace{80pt}}&\multicolumn{1}{c}{\smaller Specialty}&
    \multicolumn{2}{c}{}\\
  \end{tabular}
  \endcenter
  \endminipage
  \endlrbox
}

%
% Virtues and flaws
%

\newcommand{\vfLine}[2]{\c@r\addtocounter{vfline}{-1} #1 & #2}
\def\c@r{\gdef\c@r{\\}}
\newcounter{vfline}

\newenvironment{vf}{%
  \setcounter{vfline}{\vfNumber}
  \lrbox{\vfbox}
  \minipage{18pc}
  \center
    {\minorheading Virtue\s\ \a\ Flaw\s}\\[0.5ex]
    \begin{tabular*}{\linewidth}{%
      >{\frakfamily}r@{\extracolsep{\fill}}>{\frakfamily}r}
}{%
    \whiledo{\value{vfline} > 0}{%
      \vfLine{\rule{160pt}{1pt}}{\rule{30pt}{1pt}}%
    }
    \end{tabular*}
  \endcenter
  \endminipage
  \endlrbox
}

%
% Reputations
%

\def\grog@reputations{
  \def\rep@head{\relax}
  \def\rep@foot{\relax}
  \def\rep@grog@head{\print{Reputation} &\smaller\print{Target area}}
  \def\@reputation##1##2##3{\\\addtocounter{repline}{-1}%
                            ##1&\strut\lb##2\rb&##3}
}
\def\@reputation#1#2#3{\addtocounter{repline}{-1} #1&\strut\lb#2\rb&#3\\}
\newcounter{repline}
\def\Areputation#1#2#3{\@reputation{#1}{#2}{#3}}
\def\repLine{\Areputation%
  {\rule{7.8pc}{1pt}}{\rule{5.0pc}{1pt}}{\rule{2.3pc}{1pt}}}

\def\rep@head{\centerline{\minorheading\strut Reputation}}
\def\rep@foot{&\smaller\print{Target area}&}
\def\rep@grog@head{\relax}
\newenvironment{reputations}{%
  \setcounter{repline}{\repNumber}
  \boxpage{\reputationbox}{21pc}
  \rep@head
  \begin{tabular}{>{\handfamily}c>{\handfamily}c>{\handfamily}c}
  \rep@grog@head
}{%
    \whiledo{\value{repline} > 0}{\repLine}
    \rep@foot
  \end{tabular}
  \hfill
  \endboxpage
}


%
% Spells
%

\newcounter{spelline}
\newcommand{\SpellLine}[6][\hbox{\hspace{28pc}}]%
           {#1 & #2 & #3 & #4 & #5 \\\hline              %
            \multicolumn{5}{l}{Foci \a\ Note\s : {\handfamily #6} }\\\hline}

\def\Aspell#1#2#3#4#5#6{%
  \addtocounter{spelline}{-1}
  \SpellLine[#1]{#2}{#3}{#4}{#5}{#6}
}

\newenvironment{grimoire}{%
  \setcounter{spelline}{\spellNumber}
  \boxpage{\spellbox}{\textwidth}
    \pageheader{Magu\s\ Grimoire}
    \begin{tabular}{>{\handfamily}l|>{\handfamily}c
                   |>{\handfamily}c|>{\handfamily}c|>{\handfamily}c}\hline
                                &     &Tech \a &Total &\\
      \multicolumn{1}{c|}{Spell Title}&Level&Form    &Bonu\s&Mastery\\\hline
}{%
      \whiledo{\value{spelline} > 0}{%
        \addtocounter{spelline}{-1}%
        \SpellLine{}{}{}{}{}%
      }
      \SpellLine{}{}{}{}{}%
    \end{tabular}
  \endboxpage
}


%
% Art score definitions
%

\def\techniques#1,#2,#3,#4,#5.{%
  \def\artcreo{#1}%
  \def\artintellego{#2}%
  \def\artmuto{#3}%
  \def\artperdo{#4}%
  \def\artrego{#5}%
}

\def\forms#1,#2,#3,#4,#5,#6,#7,#8,#9.{%
  \def\artanimalem{#1}%
  \def\artaquam{#2}%
  \def\artauram{#3}%
  \def\artcorpus{#4}%
  \def\artherbam{#5}%
  \def\artignem{#6}%
  \def\artimagonem{#7}%
  \def\artmentem{#8}%
  \Forms#9.%
}
\def\Forms#1,#2.{%
  \def\artterram{#1}%
  \def\artvim{#2}%
}
  \def\artcreo{}%
  \def\artintellego{}%
  \def\artmuto{}%
  \def\artperdo{}%
  \def\artrego{}%
  \def\artanimalem{}%
  \def\artaquam{}%
  \def\artauram{}%
  \def\artcorpus{}%
  \def\artherbam{}%
  \def\artignem{}%
  \def\artimagonem{}%
  \def\artmentem{}%
  \def\artterram{}%
  \def\artvim{}%

%
% Primary data
%

\def\name#1{\def\Thename{\hand{#1}}}\name{\hspace{-1ex}}
\def\age#1{\def\Theage{\hand{#1}}}\age{\hspace{-1ex}}
\def\gender#1{\def\Thegender{\hand{#1}}}\gender{\hspace{-1ex}}
\def\player#1{\def\Theplayer{\hand{#1}}}\player{\hspace{-1ex}}
\def\born#1{\def\Theborn{\hand{#1}}}\born{\hspace{-1ex}}
\def\size#1{\def\Thesize{\hand{#1}}}\size{\hspace{-1ex}}
\def\covenant#1{\def\Thecovenant{\hand{#1}}}\covenant{\hspace{-1ex}}
\def\year#1{\def\Theyear{\hand{#1}}}\year{\hspace{-1ex}}
\def\conf#1{\def\Theconf{\hand{#1}}}\conf{\hspace{-1ex}}
\def\saga#1{\def\Thesaga{\hand{#1}}}\saga{\hspace{-1ex}}
\def\nationality#1{\def\Thenationality{\hand{#1}}}\nationality{\hspace{-1ex}}
\def\decr#1{\def\Thedecr{\hand{#1}}}\decr{\hspace{-1ex}}
\def\cconf#1{\def\Thecconf{\hand{#1}}}\cconf{\hspace{-1ex}}

%
% Characteristics
%

\newcommand\Characteristic[3][\rule{64pt}{1pt}]{%
  \expandafter\def\csname #3spec\endcsname{#1}
  \expandafter\def\csname #3score\endcsname{#2}}

\Characteristic{\rule{30pt}{1pt}}{int}
\Characteristic{\rule{30pt}{1pt}}{per}
\Characteristic{\rule{30pt}{1pt}}{str}
\Characteristic{\rule{30pt}{1pt}}{sta}
\Characteristic{\rule{30pt}{1pt}}{com}
\Characteristic{\rule{30pt}{1pt}}{pre}
\Characteristic{\rule{30pt}{1pt}}{qui}
\Characteristic{\rule{30pt}{1pt}}{dex}

%
% Personality traits
%

\newarray\eqTable
\newcounter{equipcount}
\def\eqPiece#1#2{\eqTable(\value{equipcount})={\std@Equipment{#1}{#2}}%
    \addtocounter{equipcount}{1}}
\def\std@Equipment#1#2{\hbox to 68mm{\handfamily #1\hfill} 
    & \handfamily #2}
\def\std@eqPiece{\eqPiece{}{}}
\def\stdEqCount{22}
\def\stdEqHalfCount{11}
\newenvironment{equipment}{%
  \setcounter{equipcount}{1}
}{%
  \whiledo{\value{equipcount} < \stdEqCount}{\std@eqPiece{}{}}
}

%
% Personality traits
%

\newarray\Ptable
\newcounter{ptrait}
\def\aPtrait#1#2{\Ptable(\value{ptrait})={\std@Ptrait[#1]{#2}}%
    \addtocounter{ptrait}{1}}
\newcommand\std@Ptrait[2][]%
  {\handfamily \fillRule #1\ \smallbox[\handfamily #2]}
\newenvironment{personality}{%
  \setcounter{ptrait}{1}
}{%
  \whiledo{\value{ptrait} < 7}{\aPtrait{}{}}
}

%
% Savebox
%

\newenvironment{boxpage}[2]{%
  \lrbox{#1}\minipage{#2}\center
}{%
  \endcenter\endminipage\endlrbox
}

%
% Wapons and Armour
%

\def\armour#1#2#3{\def\ArmourType{#1}\def\ArmourLoad{#2}\def\Protection{#3}}
\armour{}{}{}

%
% Misc.
%

\def\sigil#1{\def\theSigil{#1}}

\endinput

% $Log: armsheet.cls,v $
% Revision 1.1  1998/04/22 12:47:42  georg
% Initial revision
%
